==> locale-util-3.0.11.tgz: package/src/data/languages.ts <==
import type {LanguageCode} from './languageCodes'

export type Language = {
    code: LanguageCode,
    nativeName: string,
    englishName: string
}

export const languages: Language[] = [
    {
        'code': 'en',
        'nativeName': 'English',
        'englishName': 'English'
    },
    {
        'code': 'ca',
        'nativeName': 'català',
        'englishName': 'Catalan'
    },
    {
        'code': 'ar',
        'nativeName': 'العربية',
        'englishName': 'Arabic'
    },
    {
        'code': 'fa',
        'nativeName': 'فارسی',
        'englishName': 'Persian'
    },
    {
        'code': 'ps',
        'nativeName': 'پښتو',
        'englishName': 'Pashto'
    },
    {
        'code': 'sq',
        'nativeName': 'shqip',
        'englishName': 'Albanian'
    },
    {
        'code': 'hy',
        'nativeName': 'հայերեն',
        'englishName': 'Armenian'
    },
    {
        'code': 'pt',
        'nativeName': 'português',
        'englishName': 'Portuguese'
    },
    {
        'code': 'es',
        'nativeName': 'español',
        'englishName': 'Spanish'
    },
    {
        'code': 'sm',
        'nativeName': '',
        'englishName': 'Samoan'
    },
    {
        'code': 'de',
        'nativeName': 'Deutsch',
        'englishName': 'German'
    },
    {
        'code': 'nl',
        'nativeName': 'Nederlands',
        'englishName': 'Dutch'
    },
    {
        'code': 'pap',
        'nativeName': '',
        'englishName': 'Papiamento'
    },
    {
        'code': 'sv',
        'nativeName': 'svenska',
        'englishName': 'Swedish'
    },
    {
        'code': 'az',
        'nativeName': 'azərbaycan',
        'englishName': 'Azerbaijani'
    },
    {
        'code': 'bs',
        'nativeName': 'bosanski',
        'englishName': 'Bosnian'
    },
    {
        'code': 'hr',
        'nativeName': 'hrvatski',
        'englishName': 'Croatian'
    },
    {
        'code': 'sr',
        'nativeName': 'српски',
        'englishName': 'Serbian'
    },
    {
        'code': 'bn',
        'nativeName': 'বাংলা',
        'englishName': 'Bangla'
    },
    {
        'code': 'fr',
        'nativeName': 'français',
        'englishName': 'French'
    },
    {
        'code': 'bg',
        'nativeName': 'български',
        'englishName': 'Bulgarian'
    },
    {
        'code': 'rn',
        'nativeName': 'Ikirundi',
        'englishName': 'Rundi'
    },
    {
        'code': 'ms',
        'nativeName': 'Melayu',
        'englishName': 'Malay'
    },
    {
        'code': 'qu',
        'nativeName': 'Runasimi',
        'englishName': 'Quechua'
    },
    {
        'code': 'ay',
        'nativeName': '',
        'englishName': 'Aymara'
    },
    {
        'code': 'dz',
        'nativeName': 'རྫོང་ཁ',
        'englishName': 'Dzongkha'
    },
    {
        'code': 'tn',
        'nativeName': '',
        'englishName': 'Tswana'
    },
    {
        'code': 'be',
        'nativeName': 'беларуская',
        'englishName': 'Belarusian'
    },
    {
        'code': 'ru',
        'nativeName': 'русский',
        'englishName': 'Russian'
    },
    {
        'code': 'sg',
        'nativeName': 'Sängö',
        'englishName': 'Sango'
    },
    {
        'code': 'it',
        'nativeName': 'italiano',
        'englishName': 'Italian'
    },
    {
        'code': 'zh',
        'nativeName': '中文',
        'englishName': 'Chinese'
    },
    {
        'code': 'el',
        'nativeName': 'Ελληνικά',
        'englishName': 'Greek'
    },
    {
        'code': 'tr',
        'nativeName': 'Türkçe',
        'englishName': 'Turkish'
    },
    {
        'code': 'cs',
        'nativeName': 'čeština',
        'englishName': 'Czech'
    },
    {
        'code': 'da',
        'nativeName': 'dansk',
        'englishName': 'Danish'
    },
    {
        'code': 'et',
        'nativeName': 'eesti',
        'englishName': 'Estonian'
    },
    {
        'code': 'am',
        'nativeName': 'አማርኛ',
        'englishName': 'Amharic'
    },
    {
        'code': 'fi',
        'nativeName': 'suomi',
        'englishName': 'Finnish'
    },
    {
        'code': 'hif',
        'nativeName': '',
        'englishName': 'Fiji Hindi'
    },
    {
        'code': 'fj',
        'nativeName': '',
        'englishName': 'Fijian'
    },
    {
        'code': 'fo',
        'nativeName': 'føroyskt',
        'englishName': 'Faroese'
    },
    {
        'code': 'ka',
        'nativeName': 'ქართული',
        'englishName': 'Georgian'
    },
    {
        'code': 'kl',
        'nativeName': 'kalaallisut',
        'englishName': 'Kalaallisut'
    },
    {
        'code': 'ch',
        'nativeName': '',
        'englishName': 'Chamorro'
    },
    {
        'code': 'ht',
        'nativeName': '',
        'englishName': 'Haitian Creole'
    },
    {
        'code': 'hu',
        'nativeName': 'magyar',
        'englishName': 'Hungarian'
    },
    {
        'code': 'id',
        'nativeName': 'Indonesia',
        'englishName': 'Indonesian'
    },
    {
        'code': 'ga',
        'nativeName': 'Gaeilge',
        'englishName': 'Irish'
    },
    {
        'code': 'he',
        'nativeName': 'עברית',
        'englishName': 'Hebrew'
    },
    {
        'code': 'gv',
        'nativeName': 'Gaelg',
        'englishName': 'Manx'
    },
    {
        'code': 'hi',
        'nativeName': 'हिन्दी',
        'englishName': 'Hindi'
    },
    {
        'code': 'is',
        'nativeName': 'íslenska',
        'englishName': 'Icelandic'
    },
    {
        'code': 'ja',
        'nativeName': '日本語',
        'englishName': 'Japanese'
    },
    {
        'code': 'sw',
        'nativeName': 'Kiswahili',
        'englishName': 'Swahili'
    },
    {
        'code': 'ky',
        'nativeName': 'кыргызча',
        'englishName': 'Kyrgyz'
    },
    {
        'code': 'km',
        'nativeName': 'ខ្មែរ',
        'englishName': 'Khmer'
    },
    {
        'code': 'gil',
        'nativeName': '',
        'englishName': 'Gilbertese'
    },
    {
        'code': 'zdj',
        'nativeName': '',
        'englishName': ''
    },
    {
        'code': 'wni',
        'nativeName': '',
        'englishName': ''
    },
    {
        'code': 'ko',
        'nativeName': '한국어',
        'englishName': 'Korean'
    },
    {
        'code': 'kk',
        'nativeName': 'қазақ тілі',
        'englishName': 'Kazakh'
    },
    {
        'code': 'lo',
        'nativeName': 'ລາວ',
        'englishName': 'Lao'
    },
    {
        'code': 'si',
        'nativeName': 'සිංහල',
        'englishName': 'Sinhala'
    },
    {
        'code': 'ta',
        'nativeName': 'தமிழ்',
        'englishName': 'Tamil'
    },
    {
        'code': 'st',
        'nativeName': '',
        'englishName': 'Southern Sotho'
    },
    {
        'code': 'lt',
        'nativeName': 'lietuvių',
        'englishName': 'Lithuanian'
    },
    {
        'code': 'lb',
        'nativeName': 'Lëtzebuergesch',
        'englishName': 'Luxembourgish'
    },
    {
        'code': 'lv',
        'nativeName': 'latviešu',
        'englishName': 'Latvian'
    },
    {
        'code': 'tzm',
        'nativeName': 'Tamaziɣt n laṭlaṣ',
        'englishName': 'Central Atlas Tamazight'
    },
    {
        'code': 'ro',
        'nativeName': 'română',
        'englishName': 'Romanian'
    },
    {
        'code': 'mg',
        'nativeName': 'Malagasy',
        'englishName': 'Malagasy'
    },
    {
        'code': 'mh',
        'nativeName': '',
        'englishName': 'Marshallese'
    },
    {
        'code': 'mk',
        'nativeName': 'македонски',
        'englishName': 'Macedonian'
    },
    {
        'code': 'my',
        'nativeName': 'မြန်မာ',
        'englishName': 'Burmese'
    },
    {
        'code': 'mn',
        'nativeName': 'монгол',
        'englishName': 'Mongolian'
    },
    {
        'code': 'mt',
        'nativeName': 'Malti',
        'englishName': 'Maltese'
    },
    {
        'code': 'dv',
        'nativeName': '',
        'englishName': 'Divehi'
    },
    {
        'code': 'ny',
        'nativeName': '',
        'englishName': 'Nyanja'
    },
    {
        'code': 'vec',
        'nativeName': '',
        'englishName': 'Venetian'
    },
    {
        'code': 'yo',
        'nativeName': 'Èdè Yorùbá',
        'englishName': 'Yoruba'
    },
    {
        'code': 'nb',
        'nativeName': '',
        'englishName': 'Norwegian Bokmål'
    },
    {
        'code': 'no',
        'nativeName': 'norsk',
        'englishName': 'Norwegian'
    },
    {
        'code': 'nn',
        'nativeName': 'norsk nynorsk',
        'englishName': 'Norwegian Nynorsk'
    },
    {
        'code': 'ne',
        'nativeName': 'नेपाली',
        'englishName': 'Nepali'
    },
    {
        'code': 'na',
        'nativeName': '',
        'englishName': 'Nauru'
    },
    {
        'code': 'niu',
        'nativeName': '',
        'englishName': 'Niuean'
    },
    {
        'code': 'mi',
        'nativeName': 'Māori',
        'englishName': 'Māori'
    },
    {
        'code': 'ty',
        'nativeName': '',
        'englishName': 'Tahitian'
    },
    {
        'code': 'tpi',
        'nativeName': '',
        'englishName': 'Tok Pisin'
    },
    {
        'code': 'ho',
        'nativeName': '',
        'englishName': 'Hiri Motu'
    },
    {
        'code': 'fil',
        'nativeName': 'Filipino',
        'englishName': 'Filipino'
    },
    {
        'code': 'ur',
        'nativeName': 'اردو',
        'englishName': 'Urdu'
    },
    {
        'code': 'pl',
        'nativeName': 'polski',
        'englishName': 'Polish'
    },
    {
        'code': 'pau',
        'nativeName': '',
        'englishName': 'Palauan'
    },
    {
        'code': 'gn',
        'nativeName': '',
        'englishName': 'Guarani'
    },
    {
        'code': 'rw',
        'nativeName': 'Kinyarwanda',
        'englishName': 'Kinyarwanda'
    },
    {
        'code': 'sl',
        'nativeName': 'slovenščina',
        'englishName': 'Slovenian'
    },
    {
        'code': 'sk',
        'nativeName': 'slovenčina',
        'englishName': 'Slovak'
    },
    {
        'code': 'so',
        'nativeName': 'Soomaali',
        'englishName': 'Somali'
    },
    {
        'code': 'ss',
        'nativeName': '',
        'englishName': 'Swati'
    },
    {
        'code': 'th',
        'nativeName': 'ไทย',
        'englishName': 'Thai'
    },
    {
        'code': 'tg',
        'nativeName': 'тоҷикӣ',
        'englishName': 'Tajik'
    },
    {
        'code': 'tkl',
        'nativeName': '',
        'englishName': 'Tokelau'
    },
    {
        'code': 'tet',
        'nativeName': '',
        'englishName': 'Tetum'
    },
    {
        'code': 'tk',
        'nativeName': 'türkmen dili',
        'englishName': 'Turkmen'
    },
    {
        'code': 'to',
        'nativeName': 'lea fakatonga',
        'englishName': 'Tongan'
    },
    {
        'code': 'tvl',
        'nativeName': '',
        'englishName': 'Tuvalu'
    },
    {
        'code': 'uk',
        'nativeName': 'українська',
        'englishName': 'Ukrainian'
    },
    {
        'code': 'haw',
        'nativeName': 'ʻŌlelo Hawaiʻi',
        'englishName': 'Hawaiian'
    },
    {
        'code': 'uz',
        'nativeName': 'o‘zbek',
        'englishName': 'Uzbek'
    },
    {
        'code': 'vi',
        'nativeName': 'Tiếng Việt',
        'englishName': 'Vietnamese'
    },
    {
        'code': 'bi',
        'nativeName': '',
        'englishName': 'Bislama'
    },
    {
        'code': 'sn',
        'nativeName': 'chiShona',
        'englishName': 'Shona'
    },
    {
        'code': 'nd',
        'nativeName': 'isiNdebele',
        'englishName': 'North Ndebele'
    }
]

==> locale-util-3.2.2.tgz: package/src/data/languages.ts <==
import type {LanguageCode} from './languageCodes'

export type Language = {
    code: LanguageCode,
    nativeName: string,
    englishName: string
}

export const languages: Language[] = [
    {
        'code': 'en',
        'nativeName': 'English',
        'englishName': 'English'
    },
    {
        'code': 'ca',
        'nativeName': 'català',
        'englishName': 'Catalan'
    },
    {
        'code': 'ar',
        'nativeName': 'العربية',
        'englishName': 'Arabic'
    },
    {
        'code': 'fa',
        'nativeName': 'فارسی',
        'englishName': 'Persian'
    },
    {
        'code': 'ps',
        'nativeName': 'پښتو',
        'englishName': 'Pashto'
    },
    {
        'code': 'sq',
        'nativeName': 'shqip',
        'englishName': 'Albanian'
    },
    {
        'code': 'hy',
        'nativeName': 'հայերեն',
        'englishName': 'Armenian'
    },
    {
        'code': 'pt',
        'nativeName': 'português',
        'englishName': 'Portuguese'
    },
    {
        'code': 'es',
        'nativeName': 'español',
        'englishName': 'Spanish'
    },
    {
        'code': 'sm',
        'nativeName': '',
        'englishName': 'Samoan'
    },
    {
        'code': 'de',
        'nativeName': 'Deutsch',
        'englishName': 'German'
    },
    {
        'code': 'nl',
        'nativeName': 'Nederlands',
        'englishName': 'Dutch'
    },
    {
        'code': 'pap',
        'nativeName': 'Papiamentu',
        'englishName': 'Papiamento'
    },
    {
        'code': 'sv',
        'nativeName': 'svenska',
        'englishName': 'Swedish'
    },
    {
        'code': 'az',
        'nativeName': 'azərbaycan',
        'englishName': 'Azerbaijani'
    },
    {
        'code': 'bs',
        'nativeName': 'bosanski',
        'englishName': 'Bosnian'
    },
    {
        'code': 'hr',
        'nativeName': 'hrvatski',
        'englishName': 'Croatian'
    },
    {
        'code': 'sr',
        'nativeName': 'српски',
        'englishName': 'Serbian'
    },
    {
        'code': 'bn',
        'nativeName': 'বাংলা',
        'englishName': 'Bangla'
    },
    {
        'code': 'fr',
        'nativeName': 'français',
        'englishName': 'French'
    },
    {
        'code': 'bg',
        'nativeName': 'български',
        'englishName': 'Bulgarian'
    },
    {
        'code': 'rn',
        'nativeName': 'Ikirundi',
        'englishName': 'Rundi'
    },
    {
        'code': 'ms',
        'nativeName': 'Melayu',
        'englishName': 'Malay'
    },
    {
        'code': 'qu',
        'nativeName': 'Runasimi',
        'englishName': 'Quechua'
    },
    {
        'code': 'ay',
        'nativeName': '',
        'englishName': 'Aymara'
    },
    {
        'code': 'dz',
        'nativeName': 'རྫོང་ཁ',
        'englishName': 'Dzongkha'
    },
    {
        'code': 'tn',
        'nativeName': 'Setswana',
        'englishName': 'Tswana'
    },
    {
        'code': 'be',
        'nativeName': 'беларуская',
        'englishName': 'Belarusian'
    },
    {
        'code': 'ru',
        'nativeName': 'русский',
        'englishName': 'Russian'
    },
    {
        'code': 'sg',
        'nativeName': 'Sängö',
        'englishName': 'Sango'
    },
    {
        'code': 'it',
        'nativeName': 'italiano',
        'englishName': 'Italian'
    },
    {
        'code': 'zh',
        'nativeName': '中文',
        'englishName': 'Chinese'
    },
    {
        'code': 'el',
        'nativeName': 'Ελληνικά',
        'englishName': 'Greek'
    },
    {
        'code': 'tr',
        'nativeName': 'Türkçe',
        'englishName': 'Turkish'
    },
    {
        'code': 'cs',
        'nativeName': 'čeština',
        'englishName': 'Czech'
    },
    {
        'code': 'da',
        'nativeName': 'dansk',
        'englishName': 'Danish'
    },
    {
        'code': 'et',
        'nativeName': 'eesti',
        'englishName': 'Estonian'
    },
    {
        'code': 'am',
        'nativeName': 'አማርኛ',
        'englishName': 'Amharic'
    },
    {
        'code': 'fi',
        'nativeName': 'suomi',
        'englishName': 'Finnish'
    },
    {
        'code': 'hif',
        'nativeName': '',
        'englishName': 'Fiji Hindi'
    },
    {
        'code': 'fj',
        'nativeName': '',
        'englishName': 'Fijian'
    },
    {
        'code': 'fo',
        'nativeName': 'føroyskt',
        'englishName': 'Faroese'
    },
    {
        'code': 'ka',
        'nativeName': 'ქართული',
        'englishName': 'Georgian'
    },
    {
        'code': 'kl',
        'nativeName': 'kalaallisut',
        'englishName': 'Kalaallisut'
    },
    {
        'code': 'ch',
        'nativeName': '',
        'englishName': 'Chamorro'
    },
    {
        'code': 'ht',
        'nativeName': '',
        'englishName': 'Haitian Creole'
    },
    {
        'code': 'hu',
        'nativeName': 'magyar',
        'englishName': 'Hungarian'
    },
    {
        'code': 'id',
        'nativeName': 'Indonesia',
        'englishName': 'Indonesian'
    },
    {
        'code': 'ga',
        'nativeName': 'Gaeilge',
        'englishName': 'Irish'
    },
    {
        'code': 'he',
        'nativeName': 'עברית',
        'englishName': 'Hebrew'
    },
    {
        'code': 'gv',
        'nativeName': 'Gaelg',
        'englishName': 'Manx'
    },
    {
        'code': 'hi',
        'nativeName': 'हिन्दी',
        'englishName': 'Hindi'
    },
    {
        'code': 'is',
        'nativeName': 'íslenska',
        'englishName': 'Icelandic'
    },
    {
        'code': 'ja',
        'nativeName': '日本語',
        'englishName': 'Japanese'
    },
    {
        'code': 'sw',
        'nativeName': 'Kiswahili',
        'englishName': 'Swahili'
    },
    {
        'code': 'ky',
        'nativeName': 'кыргызча',
        'englishName': 'Kyrgyz'
    },
    {
        'code': 'km',
        'nativeName': 'ខ្មែរ',
        'englishName': 'Khmer'
    },
    {
        'code': 'gil',
        'nativeName': '',
        'englishName': 'Gilbertese'
    },
    {
        'code': 'zdj',
        'nativeName': '',
        'englishName': ''
    },
    {
        'code': 'wni',
        'nativeName': '',
        'englishName': ''
    },
    {
        'code': 'ko',
        'nativeName': '한국어',
        'englishName': 'Korean'
    },
    {
        'code': 'kk',
        'nativeName': 'қазақ тілі',
        'englishName': 'Kazakh'
    },
    {
        'code': 'lo',
        'nativeName': 'ລາວ',
        'englishName': 'Lao'
    },
    {
        'code': 'si',
        'nativeName': 'සිංහල',
        'englishName': 'Sinhala'
    },
    {
        'code': 'ta',
        'nativeName': 'தமிழ்',
        'englishName': 'Tamil'
    },
    {
        'code': 'st',
        'nativeName': '',
        'englishName': 'Southern Sotho'
    },
    {
        'code': 'lt',
        'nativeName': 'lietuvių',
        'englishName': 'Lithuanian'
    },
    {
        'code': 'lb',
        'nativeName': 'Lëtzebuergesch',
        'englishName': 'Luxembourgish'
    },
    {
        'code': 'lv',
        'nativeName': 'latviešu',
        'englishName': 'Latvian'
    },
    {
        'code': 'tzm',
        'nativeName': 'Tamaziɣt n laṭlaṣ',
        'englishName': 'Central Atlas Tamazight'
    },
    {
        'code': 'ro',
        'nativeName': 'română',
        'englishName': 'Romanian'
    },
    {
        'code': 'mg',
        'nativeName': 'Malagasy',
        'englishName': 'Malagasy'
    },
    {
        'code': 'mh',
        'nativeName': '',
        'englishName': 'Marshallese'
    },
    {
        'code': 'mk',
        'nativeName': 'македонски',
        'englishName': 'Macedonian'
    },
    {
        'code': 'my',
        'nativeName': 'မြန်မာ',
        'englishName': 'Burmese'
    },
    {
        'code': 'mn',
        'nativeName': 'монгол',
        'englishName': 'Mongolian'
    },
    {
        'code': 'mt',
        'nativeName': 'Malti',
        'englishName': 'Maltese'
    },
    {
        'code': 'dv',
        'nativeName': 'ދިވެހިބަސް',
        'englishName': 'Divehi'
    },
    {
        'code': 'ny',
        'nativeName': '',
        'englishName': 'Nyanja'
    },
    {
        'code': 'vec',
        'nativeName': '',
        'englishName': 'Venetian'
    },
    {
        'code': 'yo',
        'nativeName': 'Èdè Yorùbá',
        'englishName': 'Yoruba'
    },
    {
        'code': 'nb',
        'nativeName': '',
        'englishName': 'Norwegian Bokmål'
    },
    {
        'code': 'no',
        'nativeName': 'norsk',
        'englishName': 'Norwegian'
    },
    {
        'code': 'nn',
        'nativeName': '↑↑↑',
        'englishName': 'Norwegian Nynorsk'
    },
    {
        'code': 'ne',
        'nativeName': 'नेपाली',
        'englishName': 'Nepali'
    },
    {
        'code': 'na',
        'nativeName': '',
        'englishName': 'Nauru'
    },
    {
        'code': 'niu',
        'nativeName': '',
        'englishName': 'Niuean'
    },
    {
        'code': 'mi',
        'nativeName': 'Māori',
        'englishName': 'Māori'
    },
    {
        'code': 'ty',
        'nativeName': '',
        'englishName': 'Tahitian'
    },
    {
        'code': 'tpi',
        'nativeName': '',
        'englishName': 'Tok Pisin'
    },
    {
        'code': 'ho',
        'nativeName': '',
        'englishName': 'Hiri Motu'
    },
    {
        'code': 'fil',
        'nativeName': 'Filipino',
        'englishName': 'Filipino'
    },
    {
        'code': 'ur',
        'nativeName': 'اردو',
        'englishName': 'Urdu'
    },
    {
        'code': 'pl',
        'nativeName': 'polski',
        'englishName': 'Polish'
    },
    {
        'code': 'pau',
        'nativeName': '',
        'englishName': 'Palauan'
    },
    {
        'code': 'gn',
        'nativeName': 'avañe’ẽ',
        'englishName': 'Guarani'
    },
    {
        'code': 'rw',
        'nativeName': 'Kinyarwanda',
        'englishName': 'Kinyarwanda'
    },
    {
        'code': 'sl',
        'nativeName': 'slovenščina',
        'englishName': 'Slovenian'
    },
    {
        'code': 'sk',
        'nativeName': 'slovenčina',
        'englishName': 'Slovak'
    },
    {
        'code': 'so',
        'nativeName': 'Soomaali',
        'englishName': 'Somali'
    },
    {
        'code': 'ss',
        'nativeName': 'siSwati',
        'englishName': 'Swati'
    },
    {
        'code': 'th',
        'nativeName': 'ไทย',
        'englishName': 'Thai'
    },
    {
        'code': 'tg',
        'nativeName': 'тоҷикӣ',
        'englishName': 'Tajik'
    },
    {
        'code': 'tkl',
        'nativeName': '',
        'englishName': 'Tokelau'
    },
    {
        'code': 'tet',
        'nativeName': '',
        'englishName': 'Tetum'
    },
    {
        'code': 'tk',
        'nativeName': 'türkmen dili',
        'englishName': 'Turkmen'
    },
    {
        'code': 'to',
        'nativeName': 'lea fakatonga',
        'englishName': 'Tongan'
    },
    {
        'code': 'tvl',
        'nativeName': '',
        'englishName': 'Tuvalu'
    },
    {
        'code': 'uk',
        'nativeName': 'українська',
        'englishName': 'Ukrainian'
    },
    {
        'code': 'haw',
        'nativeName': 'ʻŌlelo Hawaiʻi',
        'englishName': 'Hawaiian'
    },
    {
        'code': 'uz',
        'nativeName': 'o‘zbek',
        'englishName': 'Uzbek'
    },
    {
        'code': 'vi',
        'nativeName': 'Tiếng Việt',
        'englishName': 'Vietnamese'
    },
    {
        'code': 'bi',
        'nativeName': '',
        'englishName': 'Bislama'
    },
    {
        'code': 'sn',
        'nativeName': 'chiShona',
        'englishName': 'Shona'
    },
    {
        'code': 'nd',
        'nativeName': 'isiNdebele',
        'englishName': 'North Ndebele'
    }
]
